!!! new "This sandbox is powered by [Pyodide](https://github.com/pyodide/pyodide). Preview, convert, interpolate, and explore!"

<div id="playground-results">
<div class="color-command">
<div class="swatch-bar"></div>
<div class="highlight"><pre><code>Loading coloraide...</code></pre></div>
</div>
</div>
<div id="playground-code">
<div class="highlight"><pre><code></code></pre></div>
<textarea id="playground-inputs" spellcheck="false"></textarea>
</div>

--8<-- "playground.txt"
